@@ -1,6 +1,6 @@
 /*
 Bullet Continuous Collision Detection and Physics Library
-Copyright (c) 2003-2006 Erwin Coumans  http://continuousphysics.com/Bullet/
+Copyright (c) 2003-2006 Erwin Coumans  https://bulletphysics.org
 
 This software is provided 'as-is', without any express or implied warranty.
 In no event will the authors be held liable for any damages arising from the use of this software.
@@ -25,31 +25,26 @@ TODO:
 #ifndef BT_SLIDER_CONSTRAINT_H
 #define BT_SLIDER_CONSTRAINT_H
 
-#include "LinearMath/btScalar.h"//for BT_USE_DOUBLE_PRECISION
+#include "LinearMath/btScalar.h"  //for BT_USE_DOUBLE_PRECISION
 
 #ifdef BT_USE_DOUBLE_PRECISION
-#define btSliderConstraintData2		btSliderConstraintDoubleData
-#define btSliderConstraintDataName  "btSliderConstraintDoubleData"
+#define btSliderConstraintData2 btSliderConstraintDoubleData
+#define btSliderConstraintDataName "btSliderConstraintDoubleData"
 #else
-#define btSliderConstraintData2		btSliderConstraintData 
-#define btSliderConstraintDataName	"btSliderConstraintData"
-#endif //BT_USE_DOUBLE_PRECISION
+#define btSliderConstraintData2 btSliderConstraintData
+#define btSliderConstraintDataName "btSliderConstraintData"
+#endif  //BT_USE_DOUBLE_PRECISION
 
 #include "LinearMath/btVector3.h"
 #include "btJacobianEntry.h"
 #include "btTypedConstraint.h"
 
-
-
 class btRigidBody;
 
-
-
-#define SLIDER_CONSTRAINT_DEF_SOFTNESS		(btScalar(1.0))
-#define SLIDER_CONSTRAINT_DEF_DAMPING		(btScalar(1.0))
-#define SLIDER_CONSTRAINT_DEF_RESTITUTION	(btScalar(0.7))
-#define SLIDER_CONSTRAINT_DEF_CFM			(btScalar(0.f))
-
+#define SLIDER_CONSTRAINT_DEF_SOFTNESS (btScalar(1.0))
+#define SLIDER_CONSTRAINT_DEF_DAMPING (btScalar(1.0))
+#define SLIDER_CONSTRAINT_DEF_RESTITUTION (btScalar(0.7))
+#define SLIDER_CONSTRAINT_DEF_CFM (btScalar(0.f))
 
 enum btSliderFlags
 {
@@ -67,15 +62,15 @@ enum btSliderFlags
 	BT_SLIDER_FLAGS_ERP_LIMANG = (1 << 11)
 };
 
-
-ATTRIBUTE_ALIGNED16(class) btSliderConstraint : public btTypedConstraint
+ATTRIBUTE_ALIGNED16(class)
+btSliderConstraint : public btTypedConstraint
 {
 protected:
 	///for backwards compatibility during the transition to 'getInfo/getInfo2'
-	bool		m_useSolveConstraintObsolete;
-	bool		m_useOffsetForConstraintFrame;
-	btTransform	m_frameInA;
-    btTransform	m_frameInB;
+	bool m_useSolveConstraintObsolete;
+	bool m_useOffsetForConstraintFrame;
+	btTransform m_frameInA;
+	btTransform m_frameInB;
 	// use frameA fo define limits, if true
 	bool m_useLinearReferenceFrameA;
 	// linear limits
@@ -119,21 +114,21 @@ protected:
 	btScalar m_restitutionOrthoAng;
 	btScalar m_dampingOrthoAng;
 	btScalar m_cfmOrthoAng;
-	
+
 	// for interlal use
 	bool m_solveLinLim;
 	bool m_solveAngLim;
 
 	int m_flags;
 
-	btJacobianEntry	m_jacLin[3];
-	btScalar		m_jacLinDiagABInv[3];
+	btJacobianEntry m_jacLin[3];
+	btScalar m_jacLinDiagABInv[3];
 
-    btJacobianEntry	m_jacAng[3];
+	btJacobianEntry m_jacAng[3];
 
 	btScalar m_timeStep;
-    btTransform m_calculatedTransformA;
-    btTransform m_calculatedTransformB;
+	btTransform m_calculatedTransformA;
+	btTransform m_calculatedTransformB;
 
 	btVector3 m_sliderAxis;
 	btVector3 m_realPivotAInW;
@@ -150,57 +145,57 @@ protected:
 	btScalar m_angDepth;
 	btScalar m_kAngle;
 
-	bool	 m_poweredLinMotor;
-    btScalar m_targetLinMotorVelocity;
-    btScalar m_maxLinMotorForce;
-    btScalar m_accumulatedLinMotorImpulse;
-	
-	bool	 m_poweredAngMotor;
-    btScalar m_targetAngMotorVelocity;
-    btScalar m_maxAngMotorForce;
-    btScalar m_accumulatedAngMotorImpulse;
+	bool m_poweredLinMotor;
+	btScalar m_targetLinMotorVelocity;
+	btScalar m_maxLinMotorForce;
+	btScalar m_accumulatedLinMotorImpulse;
 
-	//------------------------    
+	bool m_poweredAngMotor;
+	btScalar m_targetAngMotorVelocity;
+	btScalar m_maxAngMotorForce;
+	btScalar m_accumulatedAngMotorImpulse;
+
+	//------------------------
 	void initParams();
+
 public:
 	BT_DECLARE_ALIGNED_ALLOCATOR();
-	
+
 	// constructors
-    btSliderConstraint(btRigidBody& rbA, btRigidBody& rbB, const btTransform& frameInA, const btTransform& frameInB ,bool useLinearReferenceFrameA);
-    btSliderConstraint(btRigidBody& rbB, const btTransform& frameInB, bool useLinearReferenceFrameA);
+	btSliderConstraint(btRigidBody & rbA, btRigidBody & rbB, const btTransform& frameInA, const btTransform& frameInB, bool useLinearReferenceFrameA);
+	btSliderConstraint(btRigidBody & rbB, const btTransform& frameInB, bool useLinearReferenceFrameA);
 
 	// overrides
 
-    virtual void getInfo1 (btConstraintInfo1* info);
+	virtual void getInfo1(btConstraintInfo1 * info);
 
-	void getInfo1NonVirtual(btConstraintInfo1* info);
-	
-	virtual void getInfo2 (btConstraintInfo2* info);
+	void getInfo1NonVirtual(btConstraintInfo1 * info);
 
-	void getInfo2NonVirtual(btConstraintInfo2* info, const btTransform& transA, const btTransform& transB,const btVector3& linVelA,const btVector3& linVelB, btScalar rbAinvMass,btScalar rbBinvMass);
+	virtual void getInfo2(btConstraintInfo2 * info);
 
+	void getInfo2NonVirtual(btConstraintInfo2 * info, const btTransform& transA, const btTransform& transB, const btVector3& linVelA, const btVector3& linVelB, btScalar rbAinvMass, btScalar rbBinvMass);
 
 	// access
-    const btRigidBody& getRigidBodyA() const { return m_rbA; }
-    const btRigidBody& getRigidBodyB() const { return m_rbB; }
-    const btTransform & getCalculatedTransformA() const { return m_calculatedTransformA; }
-    const btTransform & getCalculatedTransformB() const { return m_calculatedTransformB; }
-    const btTransform & getFrameOffsetA() const { return m_frameInA; }
-    const btTransform & getFrameOffsetB() const { return m_frameInB; }
-    btTransform & getFrameOffsetA() { return m_frameInA; }
-    btTransform & getFrameOffsetB() { return m_frameInB; }
-    btScalar getLowerLinLimit() { return m_lowerLinLimit; }
-    void setLowerLinLimit(btScalar lowerLimit) { m_lowerLinLimit = lowerLimit; }
-    btScalar getUpperLinLimit() { return m_upperLinLimit; }
-    void setUpperLinLimit(btScalar upperLimit) { m_upperLinLimit = upperLimit; }
-    btScalar getLowerAngLimit() { return m_lowerAngLimit; }
-    void setLowerAngLimit(btScalar lowerLimit) { m_lowerAngLimit = btNormalizeAngle(lowerLimit); }
-    btScalar getUpperAngLimit() { return m_upperAngLimit; }
-    void setUpperAngLimit(btScalar upperLimit) { m_upperAngLimit = btNormalizeAngle(upperLimit); }
+	const btRigidBody& getRigidBodyA() const { return m_rbA; }
+	const btRigidBody& getRigidBodyB() const { return m_rbB; }
+	const btTransform& getCalculatedTransformA() const { return m_calculatedTransformA; }
+	const btTransform& getCalculatedTransformB() const { return m_calculatedTransformB; }
+	const btTransform& getFrameOffsetA() const { return m_frameInA; }
+	const btTransform& getFrameOffsetB() const { return m_frameInB; }
+	btTransform& getFrameOffsetA() { return m_frameInA; }
+	btTransform& getFrameOffsetB() { return m_frameInB; }
+	btScalar getLowerLinLimit() { return m_lowerLinLimit; }
+	void setLowerLinLimit(btScalar lowerLimit) { m_lowerLinLimit = lowerLimit; }
+	btScalar getUpperLinLimit() { return m_upperLinLimit; }
+	void setUpperLinLimit(btScalar upperLimit) { m_upperLinLimit = upperLimit; }
+	btScalar getLowerAngLimit() { return m_lowerAngLimit; }
+	void setLowerAngLimit(btScalar lowerLimit) { m_lowerAngLimit = btNormalizeAngle(lowerLimit); }
+	btScalar getUpperAngLimit() { return m_upperAngLimit; }
+	void setUpperAngLimit(btScalar upperLimit) { m_upperAngLimit = btNormalizeAngle(upperLimit); }
 	bool getUseLinearReferenceFrameA() { return m_useLinearReferenceFrameA; }
 	btScalar getSoftnessDirLin() { return m_softnessDirLin; }
 	btScalar getRestitutionDirLin() { return m_restitutionDirLin; }
-	btScalar getDampingDirLin() { return m_dampingDirLin ; }
+	btScalar getDampingDirLin() { return m_dampingDirLin; }
 	btScalar getSoftnessDirAng() { return m_softnessDirAng; }
 	btScalar getRestitutionDirAng() { return m_restitutionDirAng; }
 	btScalar getDampingDirAng() { return m_dampingDirAng; }
@@ -249,8 +244,6 @@ public:
 
 	btScalar getLinearPos() const { return m_linPos; }
 	btScalar getAngularPos() const { return m_angPos; }
-	
-	
 
 	// access for ODE solver
 	bool getSolveLinLimit() { return m_solveLinLim; }
@@ -258,9 +251,9 @@ public:
 	bool getSolveAngLimit() { return m_solveAngLim; }
 	btScalar getAngDepth() { return m_angDepth; }
 	// shared code used by ODE solver
-	void	calculateTransforms(const btTransform& transA,const btTransform& transB);
-	void	testLinLimits();
-	void	testAngLimits();
+	void calculateTransforms(const btTransform& transA, const btTransform& transB);
+	void testLinLimits();
+	void testAngLimits();
 	// access for PE Solver
 	btVector3 getAncorInA();
 	btVector3 getAncorInB();
@@ -268,84 +261,75 @@ public:
 	bool getUseFrameOffset() { return m_useOffsetForConstraintFrame; }
 	void setUseFrameOffset(bool frameOffsetOnOff) { m_useOffsetForConstraintFrame = frameOffsetOnOff; }
 
-	void setFrames(const btTransform& frameA, const btTransform& frameB) 
-	{ 
-		m_frameInA=frameA; 
-		m_frameInB=frameB;
-		calculateTransforms(m_rbA.getCenterOfMassTransform(),m_rbB.getCenterOfMassTransform());
+	void setFrames(const btTransform& frameA, const btTransform& frameB)
+	{
+		m_frameInA = frameA;
+		m_frameInB = frameB;
+		calculateTransforms(m_rbA.getCenterOfMassTransform(), m_rbB.getCenterOfMassTransform());
 		buildJacobian();
-	} 
+	}
 
-
-	///override the default global value of a parameter (such as ERP or CFM), optionally provide the axis (0..5). 
+	///override the default global value of a parameter (such as ERP or CFM), optionally provide the axis (0..5).
 	///If no axis is provided, it uses the default axis for this constraint.
-	virtual	void	setParam(int num, btScalar value, int axis = -1);
+	virtual void setParam(int num, btScalar value, int axis = -1);
 	///return the local value of parameter
-	virtual	btScalar getParam(int num, int axis = -1) const;
-	
-	virtual	int getFlags() const
-    	{
+	virtual btScalar getParam(int num, int axis = -1) const;
+
+	virtual int getFlags() const
+	{
 		return m_flags;
 	}
 
-	virtual	int	calculateSerializeBufferSize() const;
+	virtual int calculateSerializeBufferSize() const;
 
 	///fills the dataBuffer and returns the struct name (and 0 on failure)
-	virtual	const char*	serialize(void* dataBuffer, btSerializer* serializer) const;
-
-
+	virtual const char* serialize(void* dataBuffer, btSerializer* serializer) const;
 };
 
-
 ///do not change those serialization structures, it requires an updated sBulletDNAstr/sBulletDNAstr64
 
-
 struct btSliderConstraintData
 {
-	btTypedConstraintData	m_typeConstraintData;
-	btTransformFloatData m_rbAFrame; // constraint axii. Assumes z is hinge axis.
+	btTypedConstraintData m_typeConstraintData;
+	btTransformFloatData m_rbAFrame;  // constraint axii. Assumes z is hinge axis.
 	btTransformFloatData m_rbBFrame;
-	
-	float	m_linearUpperLimit;
-	float	m_linearLowerLimit;
 
-	float	m_angularUpperLimit;
-	float	m_angularLowerLimit;
+	float m_linearUpperLimit;
+	float m_linearLowerLimit;
 
-	int	m_useLinearReferenceFrameA;
+	float m_angularUpperLimit;
+	float m_angularLowerLimit;
+
+	int m_useLinearReferenceFrameA;
 	int m_useOffsetForConstraintFrame;
-
 };
 
-
 struct btSliderConstraintDoubleData
 {
-	btTypedConstraintDoubleData	m_typeConstraintData;
-	btTransformDoubleData m_rbAFrame; // constraint axii. Assumes z is hinge axis.
+	btTypedConstraintDoubleData m_typeConstraintData;
+	btTransformDoubleData m_rbAFrame;  // constraint axii. Assumes z is hinge axis.
 	btTransformDoubleData m_rbBFrame;
-	
-	double	m_linearUpperLimit;
-	double	m_linearLowerLimit;
 
-	double	m_angularUpperLimit;
-	double	m_angularLowerLimit;
+	double m_linearUpperLimit;
+	double m_linearLowerLimit;
 
-	int	m_useLinearReferenceFrameA;
+	double m_angularUpperLimit;
+	double m_angularLowerLimit;
+
+	int m_useLinearReferenceFrameA;
 	int m_useOffsetForConstraintFrame;
-
 };
 
-SIMD_FORCE_INLINE		int	btSliderConstraint::calculateSerializeBufferSize() const
+SIMD_FORCE_INLINE int btSliderConstraint::calculateSerializeBufferSize() const
 {
 	return sizeof(btSliderConstraintData2);
 }
 
-	///fills the dataBuffer and returns the struct name (and 0 on failure)
-SIMD_FORCE_INLINE	const char*	btSliderConstraint::serialize(void* dataBuffer, btSerializer* serializer) const
+///fills the dataBuffer and returns the struct name (and 0 on failure)
+SIMD_FORCE_INLINE const char* btSliderConstraint::serialize(void* dataBuffer, btSerializer* serializer) const
 {
-
-	btSliderConstraintData2* sliderData = (btSliderConstraintData2*) dataBuffer;
-	btTypedConstraint::serialize(&sliderData->m_typeConstraintData,serializer);
+	btSliderConstraintData2* sliderData = (btSliderConstraintData2*)dataBuffer;
+	btTypedConstraint::serialize(&sliderData->m_typeConstraintData, serializer);
 
 	m_frameInA.serialize(sliderData->m_rbAFrame);
 	m_frameInB.serialize(sliderData->m_rbBFrame);
@@ -362,7 +346,4 @@ SIMD_FORCE_INLINE	const char*	btSliderConstraint::serialize(void* dataBuffer, bt
 	return btSliderConstraintDataName;
 }
 
-
-
-#endif //BT_SLIDER_CONSTRAINT_H
-
+#endif  //BT_SLIDER_CONSTRAINT_H
